@@ -7,12 +7,18 @@ from adminvisualsortable.views import get_fk_name, get_model_inlines
 from django.db.models import ForeignKey
 
 class AdminVisualSortableInlineMixin:
+    ''' Enable sortable for Inline Models '''
     is_adminvisualsortable = True
 
 class AdminVisualSortableBaseMixin:
+    ''' Admin Model mandatory if Inlines are Sortables'''
     is_adminvisualsortable = False
-    ''' Admin Model mandatory if Inlines has Sortable Elements '''
-    change_form_template =  str(Path('change_form.html'))
+    @property
+    def change_form_template(self):
+        if getattr(self, 'add_tabbed_item'):
+            return str(Path('tabbed_change_form.html'))
+        else:
+            return str(Path('change_form.html'))
 
     def has_sort_elements(self, object_id):
         ''' Check if Parent Model has Sortable Inlines '''
@@ -37,20 +43,10 @@ class AdminVisualSortableBaseMixin:
         )
 
 class AdminVisualSortableMixin(AdminVisualSortableBaseMixin):
-    ''' Admin Model for the Sortable Parent Model'''
+    ''' Admin Model Mixin for Sortable Model'''
     is_adminvisualsortable = True
     @property
     def change_list_template(self):
         opts = self.model._meta
         app_label = opts.app_label
         return str(Path('change_list.html'))
-
-class AdminVisualSortableTabbedMixin(AdminVisualSortableMixin):
-    ''' Admin Model With Correct Template if Tabbed Admin is in Use '''
-    is_adminvisualsortable = True
-    change_form_template =  str(Path('tabbed_change_form.html'))
-
-class AdminVisualSortableBaseTabbedMixin(AdminVisualSortableMixin):
-    ''' Admin Model With Correct Template if Tabbed Admin is in Use '''
-    is_adminvisualsortable = False
-    change_form_template =  str(Path('tabbed_change_form.html'))
