@@ -1,28 +1,22 @@
 #-*- coding: utf-8 -*-
 from django import template
-from django.urls import reverse, NoReverseMatch
+from django.urls import reverse
 from django.conf import settings
+
 register = template.Library()
 
 @register.filter(name='get_child_sortable_list')
 def get_child_sortable_list(value):
     try:
         value_list = value.split('/')
-        if len(value_list) == 5:
-            obj_id = 0
-            model_name = value_list[3]
-            app_name = value_list[2]
-        else:
-            obj_id = value_list[4]
-            model_name = value_list[3]
-            app_name = value_list[2]
-        return reverse('adminvisualsortable:sortable inlines', kwargs={'app': app_name, 'modelparentname': model_name, 'model_id': obj_id })
+        obj_id = value_list[-3]
+        model_name = value_list[-4]
+        app_name = value_list[-5]
     except ValueError:
-        return '/?error=ValueError'
+        return None
     except IndexError:
-        return '/?error=InextError'
-    except NoReverseMatch:
-        return '/?error=NoReverseMatch'
+        return None
+    return reverse('adminvisualsortable:sortable inlines', kwargs={'app': app_name, 'modelparentname': model_name, 'model_id': obj_id })
 
 
 @register.filter(name='get_parent_visualorder_url')
